pro ssw_average_images, index, data, sindex, sdata, $
      ref_image=ref_image, above_radius=above_radius, disk=disk, $
      annulus=annulus, invert_limb=invert_limb, sum_images=sum_images
;
;+
;   Name: ssw_sum_images
;
;   Purpose: sum/average N-images, optionally only above limb, annulus, etc.
;
;   Input Parameters:
;      index, data - any SSW standards, assume more than 1 image
;      
;   Output Parameters:
;      sindex, sdata - the summed/averaged output image with history added
;
;   Keyword Parameters:
;      ref_image - reference image number or index - default is midpoint
;      above_radius - only sum/average above this raduis (floating point ok)
;                     [ 1.0=photospheric limb ]
;      disk - only sum/average on-disk pixels
;      annulus - optional 2 element annulus, in radii - for example [1.0,1.2]
;      invert - optionally, invert the summed/averaged pixels
;      sum_images - if set, just sum not average desired pixels
;
;   History:
;      16-Nov-2000 - S.L.Freeland
;   
;   Restrictions:
;      assume image alignment done prior to call 
;-

nimg=data_chk(data,/nimage)
if nimg lt 2 or nimg ne n_elements(index) then begin 
   box_message,['Need at least 2 images (index,data)',$
                'IDL> ssw_average_images, index, data, sindex,sdata,[KEYWORDS]']
   return
endif

; select reference
case 1 of 
   data_chk(ref_image,/struct):   refss=tim2dset(index,ref_image)
   data_chk(ref_image,/undefined):refss=nimg/2
   else: refss=ref_image(0)
endcase

allmask=make_array(data_chk(data,/nx),data_chk(data,/ny),/long,value=1)

; select solar mask, if any
case 1 of 
   keyword_set(above_radius): $
      summask=solar_mask(index(refss),data(*,*,refss),/outside)
   keyword_set(annulus): $
      summask=solar_mask(index(refss),data(*,*,refss),annulus=annulus)
   keyword_set(disk): $
      summask=solar_mask(index(refss),data(*,*,refss)
   else: smask=allmask
endcase
rmask=smask-1               ; inverted mask (non summed/averaged)

spart=(total(data,3)  * smask)/([nimg,1])(keyword_set(sum_images))
rpart=data(*,*,refss) * rmask)
retval=spart + rpart 

stop
return
end
